import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorCheckbox extends StatelessWidget {
  final String? title;
  final bool value;
  final bool disabled;
  final Function(bool?)? onChanged;

  const SeniorCheckbox({
    Key? key,
    this.title,
    required this.value,
    required this.onChanged,
    this.disabled = false,
  }) : super(key: key);

  Widget buildCheckbox() {
    return SizedBox(
      width: Checkbox.width,
      height: Checkbox.width,
      child: Container(
        decoration: BoxDecoration(
          color: SeniorColors.pureWhite,
          border: Border.all(
            color: disabled
                ? SeniorColors.secondaryColor300
                : value
                    ? SeniorColors.primaryColor
                    : SeniorColors.secondaryColor600,
            width: 1,
          ),
          borderRadius: BorderRadius.circular(3),
        ),
        child: Theme(
          data: ThemeData(
            unselectedWidgetColor: Colors.transparent,
            disabledColor: Colors.transparent,
          ),
          child: Checkbox(
            value: value,
            onChanged: !disabled ? onChanged : null,
            activeColor: Colors.transparent,
            checkColor: disabled
                ? SeniorColors.secondaryColor300
                : SeniorColors.primaryColor,
            materialTapTargetSize: MaterialTapTargetSize.padded,
          ),
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return title == null
        ? buildCheckbox()
        : Row(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding: const EdgeInsets.fromLTRB(0, 0, 8.0, 0),
                child: buildCheckbox(),
              ),
              Flexible(
                child: Text(
                  title ?? '',
                  style: SeniorTypography.text(
                    color: disabled
                        ? SeniorColors.secondaryColor300
                        : SeniorColors.neutralColor900,
                  ),
                ),
              ),
            ],
          );
  }
}
